%function [F,F2,F3,F4,FJ] = regularwave_pontoon() % Regular wave force computation 
% Pontoon dimensions (barge) 
B = 28;                          % Width [m]
L = 68;                          % Length [m]             
d = 10.5;                        % Draft [m]
f = 5;                           % Flange width [m]

% Jacket parameters 
h = 140;                      % Water depth [m]
D = 1.1;                      % Diameter [m]
C_d = 0.9;                    % Drag coefficient []
C_m = 2.0;                    % Mass coefficient []

% Integral parameters
z = -d;                          % z, vertical downwards in sea [m]   
zm= z/2;                         % 

% Hydrostatic parameters 
g = 9.81;                        % Gravity acceleration [m/s^2]
rho_sea = 1025;                  % Sea water density [kg/m^3]
A_unit = 1;                      % Unit amplitude

% Establish length and time step vector
antime = 45;                    % Analysis length, approx 2-3 periods [s]
dt = 0.2;                       % Length of timesteps [s]
t = 0:dt:antime;                % Timestep array 
nstep_t = length(t);            % Number of steps in timestep array

% Establish empty vectors for force storing
F_fk3 = zeros(nstep_t,3);       % Heave
F_fk2 = zeros(nstep_t,3);       % Sway
F_fk4 = zeros(nstep_t,3);       % Roll

F_d3 = zeros(nstep_t,3);        % Heave
F_d2 = zeros(nstep_t,3);        % Sway
F_d4 = zeros(nstep_t,3);        % Roll 

F_d = zeros(nstep_t,3);        % Drag
F_m = zeros(nstep_t,3);        % Inertia

% Wave periods and corresponding frequency 
Tp = [5,6,7];                   % Chosen wave periods [s]
omega_p = zeros(1,3);

for i = 1:length(Tp)
omega_p(i) = 2*pi/Tp(i);            % Circular frequency [rad/s]
end

% Added mass coefficients for the chosen periods 
ma2 = [1.000E+06, 2.000E+06, 2.900E+06];    % Added mass, sway [kg]
ma3 = [7.650E+05, 1.840E+06, 2.700E+06];    % Added mass, heave [kg]
ma4 = [1.117E+06, 1.148E+06, 1.160E+06];    % Added mass, roll [kg]

% Compute wave forces
for i = 1:3
    T_p = Tp(i);                 % Select period
    omega = omega_p(i);          % Select circular frequency [rad/s]
    k = (omega^2)/g;             % Calculate wave number 
    for d_t = 1:nstep_t
    % Froude Kryloff forces 
        % Sway 
        % F_fk2(d_t,i) = rho_sea*g*A_unit*B*((1-exp(z*k))/k)*2*sin(2*L/2)*cos(omega*t(d_t))
         F_fk2(d_t,i) = rho_sea*g*A_unit*B*((1-exp(z*k))/k)*...
           sin(omega*t(d_t)-k*(-L/2)) - ... x = -L/2
           rho_sea*g*A_unit*B*((1-exp(z*k))/k)*sin(omega*t(d_t)...
           -k*(L/2)) ; % x=l/2
       
        % Heave
        %F_fk3(d_t,i) = rho_sea*g*A_unit*exp(k*z)*(B+2*f)*(2/k)*...
            sin(k*(2*f+L)/2)*sin(omega*t(d_t));
        F_fk3(d_t,i) = (ma3(i)/(2*f+L))*(-(omega)^2)*A_unit*exp(k*zm)*...
           (cos(omega*t(d_t))*(k*(2*f+L)*cos(k*(2*f+L)/2)-2*sin(k*(2*f+L)/2))/(k^2));
        % Roll
        % F_fk4(d_t,i) =  rho_sea*g*A_unit*exp(k*z)*(B+2*f)*((L/k)*cos(k*L/2)-(2/k^2)*sin(k*L/2))
        F_fk4(d_t,i) = rho_sea*g*A_unit*exp(k*z)*(B+2*f)*...
           (cos(omega*t(d_t))*(k*(2*f+L)*cos(k*(2*f+L)/2)-2*sin(k*(2*f+L)/2))/(k^2));
       
       
    % Diffraction forces 
       % Sway
       % F_d2(d_t,i) = A_unit*ma2(i)*(omega^2)*((1-exp(k*z))/k)*cos(omega*t(d_t)); 
       F_d2(d_t,i) = ((omega)^2*A_unit*ma2(i)/d)*((1-exp(z*k))/k)*...
           cos(omega*t(d_t)-k*0);
       % Heave 
       %F_d3(d_t,i) = -A_unit*ma3(i)*(omega^2)*exp(k*zm)*(2/k)*sin(k*L/2)*sin(omega*t(d_t));
       F_d3(d_t,i) = (ma3(i)/(2*f+L))*(-(omega)^2)*A_unit*exp(k*zm)*...
           (2/k)*sin(k*(2*f+L)/2)*sin(omega*t(d_t));
       
       % Roll 
       % F_d4(d_t,i) = -A_unit*ma3(i)*(omega^2)*exp(k*zm)*((L/k)*cos(k*L/2)-(2/(k^2))*sin(k*L/2));
       F_d4(d_t,i)= (ma3(i)/(2*f+L))*(-(omega)^2)*A_unit*exp(k*zm)*...
           (cos(omega*t(d_t))*(k*(2*f+L)*cos(k*(2*f+L)/2)-2*sin(k*(2*f+L)/2))/(k^2));
       
           
           
        
   % Regular wave force on jacket 
       % Drag force
       F_d(d_t,i) = 0.5*rho_sea*C_d*D*(omega^2)*A_unit^2*...
           ((0.25*sinh(2*k*h)+0.5*k*h)/(k*(sinh(k*h)^2)))*sin(omega*d_t)*abs(sin(omega*d_t));
       % Mass force
       F_m(d_t,i) = rho_sea*(pi*(D^2)/4)*C_m*(omega^2)*A_unit*(1/k)*cos(omega*d_t);
       
    end
end

% Create total force matrices 
F2 = F_fk2+F_d2;
F3 = F_fk3+F_d3;
F4 = F_fk4+F_d4;
FJ = 4*(F_d+F_m); 
F = [F2,F3,F4,FJ]';

% Write to tabels for ANSYS 
%xlswrite('waveforce_reg1.xlsx', F2,1) 
%xlswrite('waveforce_reg1.xlsx', F3,2)
%xlswrite('waveforce_reg1.xlsx', F4,3)
%xlswrite('waveforce_reg1.xlsx', FJ,4)
xlswrite('waveforce_reg_60_02.xlsx',F)

% Plot wave forces figure
figure
hold on
plot(t,F(1,:))
plot(t,F(4,:))
plot(t,F(7,:))
title('Pontoon Force (Unit Amplitude, T = 5s) ')
xlabel('Time (s)') % x-axis label
ylabel('Force [N], Moment [Nm]')
legend('Sway Force, Tp = 5s','Heave Force, Tp = 5s','Roll Moment, Tp = 5s')
%plot(t,F(10,:))
saveas(gcf,'F_T5.png')

figure
hold on
plot(t,F(2,:))
plot(t,F(5,:))
plot(t,F(8,:))
title('Pontoon Force (Unit Amplitude, T = 6s) ')
xlabel('Time (s)') % x-axis label
ylabel('Force [N], Moment [Nm]')
legend('Sway Force, Tp = 6s','Heave Force, Tp = 6s','Roll Moment, Tp = 6s')
saveas(gcf,'F_T6.png')

figure
hold on
plot(t,F(3,:))
plot(t,F(6,:))
plot(t,F(9,:))
title('Pontoon Force (Unit Amplitude, T = 7s) ')
xlabel('Time (s)') % x-axis label
ylabel('Force [N], Moment [Nm]')
legend('Sway Force, Tp = 7s','Heave Force, Tp = 7s','Roll Moment, Tp = 7s')
saveas(gcf,'F_T7.png')






        
        
    




